@@ -1,7 +1,7 @@
 #!/bin/sh
-MD5=bfaff4556a9ca63ad657a3e1b2610b3c
-BASENAME=libgoto_p4_128-r0.94
-DESCR="Intel P4, 128k cache, single-threaded, Linux"
+MD5=19891bde93e7233524aa33a30f0a5c25
+BASENAME=libgoto_p4_256p-r0.97
+DESCR="Intel P4, 256k cache, multi-threaded, Linux"
 nb -download http://www.cs.utexas.edu/users/kgoto/libraries/$BASENAME.so.gz $BASENAME.so.gz
 case "`nb -md5 $BASENAME.so.gz | awk '{print $4}'`" in
 	$MD5) ;;
